"""Django Admin Site configuration for socialprofiles"""

from axes.admin import AccessAttemptAdmin, AccessLogAdmin
from axes.models import AccessAttempt, AccessLog
from django.contrib import admin
from django.contrib.auth.admin import UserAdmin as BaseUserAdmin
from django.utils.translation import gettext_lazy as _
from django_otp.plugins.otp_static.admin import StaticDeviceAdmin
from django_otp.plugins.otp_static.models import StaticDevice
from django_otp.plugins.otp_totp.admin import TOTPDeviceAdmin
from django_otp.plugins.otp_totp.models import TOTPDevice
from image_cropping.admin import ImageCroppingMixin
from oauth2_provider.admin import (
    AccessTokenAdmin,
    ApplicationAdmin,
    GrantAdmin,
    IDTokenAdmin,
    RefreshTokenAdmin,
)
from oauth2_provider.models import (
    get_access_token_model,
    get_application_model,
    get_grant_model,
    get_id_token_model,
    get_refresh_token_model,
)
from social_django.admin import AssociationOption, NonceOption, UserSocialAuthOption
from social_django.models import Association, Nonce, UserSocialAuth
from user_sessions.admin import SessionAdmin
from user_sessions.models import Session

from socialprofile.models import SocialProfile

# from rest_framework.authtoken.admin import TokenAdmin
# from rest_framework.authtoken.models import Token, TokenProxy


@admin.register(SocialProfile)
class CustomUserAdmin(ImageCroppingMixin, BaseUserAdmin):
    """Sets up the custom user admin display"""

    fieldsets = (
        (None, {"fields": ("email", "username", "password")}),
        (_("Personal info"), {"fields": ("first_name", "last_name", "phone_number")}),
        (
            _("Permissions"),
            {
                "fields": (
                    "is_active",
                    "is_staff",
                    "is_superuser",
                    "groups",
                    "user_permissions",
                )
            },
        ),
        (
            _("Important dates"),
            {"fields": ("last_login", "date_joined", "date_of_birth")},
        ),
        (_("Common Info"), {"fields": ("country", "gender", "url", "image_url")}),
        (
            _("Avatar"),
            {
                "fields": (
                    "image",
                    "cropping",
                    "cropping_free",
                )
            },
        ),
        (
            _("Staff"),
            {
                "fields": (
                    "sort",
                    "visible",
                    "title",
                    "role",
                    "function_01",
                    "function_02",
                    "function_03",
                    "function_04",
                    "function_05",
                    "function_06",
                    "function_07",
                    "function_08",
                    "function_09",
                    "function_10",
                )
            },
        ),
        (
            _("Providers"),
            {
                "fields": (
                    "edited_by_user",
                    "edited_by_google",
                    "edited_by_twitter",
                    "edited_by_facebook",
                    "edited_by_instagram",
                    "edited_by_live",
                )
            },
        ),
        (
            "Google",
            {
                "fields": (
                    "google_username",
                    "google_email",
                    "google_isPlusUser",
                    "google_url",
                    "google_circledByCount",
                    "google_language",
                    "google_kind",
                    "google_verified",
                    "google_avatar",
                )
            },
        ),
        (
            "Twitter",
            {
                "fields": (
                    "twitter_username",
                    "twitter_email",
                    "twitter_url",
                    "twitter_language",
                    "twitter_verified",
                    "twitter_avatar",
                )
            },
        ),
        (
            "Facebook",
            {
                "fields": (
                    "facebook_username",
                    "facebook_email",
                    "facebook_url",
                    "facebook_avatar",
                )
            },
        ),
        (
            "Instagram",
            {
                "fields": (
                    "instagram_username",
                    "instagram_email",
                    "instagram_url",
                    "instagram_avatar",
                )
            },
        ),
        (
            "Live",
            {
                "fields": (
                    "live_username",
                    "live_email",
                    "live_url",
                    "live_language",
                    "live_avatar",
                )
            },
        ),
    )
    add_fieldsets = (
        (
            None,
            {
                "classes": ("wide",),
                "fields": ("username", "email", "password1", "password2"),
            },
        ),
    )
    readonly_fields = [
        # "email",
        "last_login",
        "date_joined",
        "edited_by_user",
        "edited_by_google",
        "edited_by_twitter",
        "edited_by_facebook",
        "edited_by_instagram",
        "edited_by_live",
        "google_username",
        "google_isPlusUser",
        "google_url",
        "google_circledByCount",
        "google_language",
        "google_kind",
        "google_verified",
        "google_avatar",
        "twitter_username",
        "twitter_url",
        "twitter_language",
        "twitter_verified",
        "twitter_avatar",
        "facebook_username",
        "facebook_url",
        "facebook_avatar",
        "instagram_username",
        "instagram_url",
        "instagram_avatar",
        "live_username",
        "live_url",
        "live_language",
        "live_avatar",
    ]
    # form = UserChangeForm
    # add_form = UserCreationForm
    list_display = (
        "email",
        "username",
        "gender",
        "first_name",
        "last_name",
        "is_active",
        "edited_by_user",
        "edited_by_google",
        "edited_by_twitter",
        "edited_by_facebook",
        "edited_by_instagram",
        "edited_by_live",
        "visible",
        "date_joined",
        "last_login",
    )
    search_fields = ("email", "first_name", "last_name", "groups", "user_permissions")

    ordering = (
        "last_login",
        "date_joined",
        "email",
    )


# social_django
class ProxyUserSocialAuth(UserSocialAuth):
    """Create UserSocialAuth proxy model for OAuth social_django"""

    class Meta:
        proxy = True
        verbose_name = f"OAuth: {UserSocialAuth._meta.verbose_name}"
        verbose_name_plural = f"OAuth: {UserSocialAuth._meta.verbose_name_plural}"


class ProxyNonce(Nonce):
    """Create Nonce proxy model for OAuth social_django"""

    class Meta:
        proxy = True
        verbose_name = f"OAuth: {Nonce._meta.verbose_name}"
        verbose_name_plural = f"OAuth: {Nonce._meta.verbose_name_plural}"


class ProxyAssociation(Association):
    """Create Association proxy model for OAuth social_django"""

    class Meta:
        proxy = True
        verbose_name = f"OAuth: {Association._meta.verbose_name}"
        verbose_name_plural = f"OAuth: {Association._meta.verbose_name_plural}"


admin.site.unregister(UserSocialAuth)
admin.site.unregister(Nonce)
admin.site.unregister(Association)
admin.site.register(ProxyUserSocialAuth, UserSocialAuthOption)
admin.site.register(ProxyNonce, NonceOption)
admin.site.register(ProxyAssociation, AssociationOption)


# rest_framework
# class ProxyTokenAdmin(TokenProxy):
#     """Create TokenProxy proxy model for rest_framework"""
#
#     class Meta:
#         proxy = True
#         verbose_name = f"Rest Framework: {TokenProxy._meta.verbose_name}"
#         verbose_name_plural = f"Rest Framework: {TokenProxy._meta.verbose_name_plural}"
#
#
# admin.site.unregister(TokenProxy)
# admin.site.register(TokenProxy, ProxyTokenAdmin)


# django_otp
class ProxyStaticDevice(StaticDevice):
    """Create StaticDevice proxy model for OAuth social_django"""

    class Meta:
        proxy = True
        verbose_name = f"Otp: {StaticDevice._meta.verbose_name}"
        verbose_name_plural = f"Otp: {StaticDevice._meta.verbose_name_plural}"


class ProxyTOTPDevice(TOTPDevice):
    """Create TOTPDevice proxy model for OAuth social_django"""

    class Meta:
        proxy = True
        verbose_name = f"Otp: {TOTPDevice._meta.verbose_name}"
        verbose_name_plural = f"Otp: {TOTPDevice._meta.verbose_name_plural}"


admin.site.unregister(StaticDevice)
admin.site.unregister(TOTPDevice)
admin.site.register(ProxyStaticDevice, StaticDeviceAdmin)
admin.site.register(ProxyTOTPDevice, TOTPDeviceAdmin)


# user_sessions
class ProxySession(Session):
    """Create Session proxy model for user_session"""

    class Meta:
        proxy = True
        verbose_name = f"Monitor: {Session._meta.verbose_name}"
        verbose_name_plural = f"Monitor: {Session._meta.verbose_name_plural}"


admin.site.unregister(Session)
admin.site.register(ProxySession, SessionAdmin)


# axes
class ProxyAccessAttempt(AccessAttempt):
    """Create AccessAttempt proxy model for axes"""

    class Meta:
        proxy = True
        verbose_name = f"Monitor: {AccessAttempt._meta.verbose_name}"
        verbose_name_plural = f"Monitor: {AccessAttempt._meta.verbose_name_plural}"


class ProxyAccessLog(AccessLog):
    """Create Axes proxy model for axes"""

    class Meta:
        proxy = True
        verbose_name = f"Monitor: {AccessLog._meta.verbose_name}"
        verbose_name_plural = f"Monitor: {AccessLog._meta.verbose_name_plural}"


admin.site.unregister(AccessAttempt)
admin.site.unregister(AccessLog)
admin.site.register(ProxyAccessAttempt, AccessAttemptAdmin)
admin.site.register(ProxyAccessLog, AccessLogAdmin)

# oauth2_provider
Application = get_application_model()
Grant = get_grant_model()
AccessToken = get_access_token_model()
RefreshToken = get_refresh_token_model()
IDToken = get_id_token_model()


class ProxyApplication(Application):
    """Create Application proxy model for oauth2_provider"""

    class Meta:
        proxy = True
        verbose_name = f"Token: {Application._meta.verbose_name}"
        verbose_name_plural = f"Token: {Application._meta.verbose_name_plural}"


class ProxyGrant(Grant):
    """Create Grant proxy model for oauth2_provider"""

    class Meta:
        proxy = True
        verbose_name = f"Token: {Grant._meta.verbose_name}"
        verbose_name_plural = f"Token: {Grant._meta.verbose_name_plural}"


class ProxyAccessToken(AccessToken):
    """Create AccessToken proxy model for oauth2_provider"""

    class Meta:
        proxy = True
        verbose_name = f"Token: {AccessToken._meta.verbose_name}"
        verbose_name_plural = f"Token: {AccessToken._meta.verbose_name_plural}"


class ProxyRefreshToken(RefreshToken):
    """Create RefreshToken proxy model for oauth2_provider"""

    class Meta:
        proxy = True
        verbose_name = f"Token: {RefreshToken._meta.verbose_name}"
        verbose_name_plural = f"Token: {RefreshToken._meta.verbose_name_plural}"


class ProxyIDToken(IDToken):
    """Create IDToken proxy model for oauth2_provider"""

    class Meta:
        proxy = True
        verbose_name = f"Token: {IDToken._meta.verbose_name}"
        verbose_name_plural = f"Token: {IDToken._meta.verbose_name_plural}"


admin.site.unregister(Application)
admin.site.unregister(Grant)
admin.site.unregister(AccessToken)
admin.site.unregister(RefreshToken)
admin.site.unregister(IDToken)
admin.site.register(ProxyApplication, ApplicationAdmin)
admin.site.register(ProxyGrant, GrantAdmin)
admin.site.register(ProxyAccessToken, AccessTokenAdmin)
admin.site.register(ProxyRefreshToken, RefreshTokenAdmin)
admin.site.register(ProxyIDToken, IDTokenAdmin)



"""
    Master URL Pattern List for the application.  Most of the patterns here should be top-level
    pass-offs to sub-modules, who will have their own urls.py defining actions within.
"""

from django.conf.urls import include
from django.contrib.auth.decorators import login_required
from django.urls import path, re_path
from django.views.decorators.cache import never_cache

# from rest_framework_jwt.views import obtain_jwt_token, refresh_jwt_token, verify_jwt_token
from . import views

urlpatterns = [
    # Profile Self View
    path(
        "",
        never_cache(login_required(views.SocialProfileView.as_view())),
        name="sp_profile_view",
    ),
    path("login/", never_cache(login_required(views.home))),
    path("logout/", never_cache(views.logout), name="sp_logout_page"),
    path("done/", views.done, name="done"),
    # re_path(r'^ajax-auth/(?P<backend>[^/]+)/$', views.ajax_auth, name='ajax-auth'),
    # New Profile
    path(
        "new-profile/",
        login_required(views.SocialProfileWelcome.as_view()),
        name="new_profile",
    ),
    # New Profile's Association
    path(
        "new-association/",
        login_required(views.SocialProfileView.as_view()),
        name="new_profile_association",
    ),
    # Login Error
    path(
        "login-error/",
        login_required(views.SocialProfileView.as_view()),
        name="login_error",
    ),
    # Login Error
    path(
        "inactive/",
        login_required(views.SocialProfileView.as_view()),
        name="inactive",
    ),
    # Profile Disconnected
    path(
        "profile-disconnected/",
        login_required(views.SocialProfileView.as_view()),
        name="profile_disconnected",
    ),
    # Profile View All
    path(
        "view/all/",
        login_required(views.SocialProfileViewAll.as_view()),
        name="sp_profile_view_all",
    ),
    # Profile Other View
    re_path(
        r"^view/(?P<username>\w.+)/$",
        login_required(views.SocialProfileView.as_view()),
        name="sp_profile_other_view_page",
    ),
    # Profile Edit
    path(
        # "edit/<str:username>/",
        "edit/<int:pk>/",
        never_cache(login_required(views.SocialProfileEditView.as_view())),
        name="sp_profile_edit_page",
    ),
    # Select Sign Up Method
    path("select/", never_cache(views.SelectAuthView.as_view()), name="sp_select_page"),
    # Delete
    path(
        "delete/",
        login_required(views.DeleteSocialProfileView.as_view()),
        name="sp_delete_page",
    ),
    # Social Auth
    path("", include("social_django.urls", namespace="social")),
    # User Sessions
    path("", include("user_sessions.urls", "user_sessions")),
    # OAuth2 Token
    path("o/", include("oauth2_provider.urls", namespace="oauth2_provider")),
    # Rest Framework
    path("api-auth/", include("rest_framework.urls", namespace="rest_framework")),
    # path("api-token-auth/", obtain_jwt_token),
    # path("api-token-refresh/', refresh_jwt_token),
    # path("api-token-verify/", verify_jwt_token),
    # One-Time-Password
    # path("", include('two_factor.urls', 'two_factor')),
    # path("check_username_exist/", login_required(views.check_username_exist), name="check_username_exist"),
]



# Generated by Django 3.2.13 on 2022-05-03 21:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0025_auto_20220317_1059"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialprofile",
            name="edited_by_live",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Live edited"
            ),
        ),
    ]



# Generated by Django 2.2.24 on 2021-12-02 21:16

import django.core.validators
import django_countries.fields
from django.db import migrations, models

import socialprofile.models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0018_auto_20211130_1937"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="country",
            field=django_countries.fields.CountryField(
                blank=True, max_length=2, null=True, verbose_name="Country"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="edited_by_provider",
            field=models.NullBooleanField(
                default=False, verbose_name="Provider edited"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="edited_by_user",
            field=models.NullBooleanField(default=False, verbose_name="User edited"),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="is_active",
            field=models.NullBooleanField(
                default=True,
                help_text="Designates whether this user should be treated as active. Unselect this instead of deleting accounts.",
                verbose_name="Active",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="is_staff",
            field=models.NullBooleanField(
                default=False,
                help_text="Designates whether the user can log into this admin site.",
                verbose_name="Staff",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="sort",
            field=socialprofile.models.IntegerRangeField(
                blank=True, default=1, null=True, verbose_name="Sort order"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="username",
            field=models.CharField(
                error_messages={"unique": "A user with that username already exists."},
                help_text="Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only",
                max_length=30,
                unique=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^[\\w.@+-]+$",
                        "Enter a valid username. This value may contain 30 characters or fewer. Only letters, numbers and @/./+/-/_ characters",
                    )
                ],
                verbose_name="Username",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="visible",
            field=models.BooleanField(
                choices=[(True, "Yes"), (False, "No")],
                default=True,
                help_text="Designates whether this user should be visible by all. Select 'no' this make your account private!",
                verbose_name="Public",
            ),
        ),
    ]



from functools import wraps

from django.shortcuts import render
from django.template import RequestContext


# ToDo: not needed !?
def render_to(tpl):
    def decorator(func):
        @wraps(func)
        def wrapper(request, *args, **kwargs):
            out = func(request, *args, **kwargs)
            if isinstance(out, dict):
                out = render(tpl, out, RequestContext(request))
            return out

        return wrapper

    return decorator



"""Test's urls view for django-errors"""

from django.conf.urls.i18n import i18n_patterns
from django.contrib import admin
from django.urls import include, path, re_path
from django.views.i18n import JavaScriptCatalog
from django_errors import views as errors_views

urlpatterns = [
    path("", include("django_errors.urls")),
    path("admin/", admin.site.urls),
]

urlpatterns += i18n_patterns(
    re_path(r"^jsi18n/$", JavaScriptCatalog.as_view(), name="javascript-catalog"),
    re_path(r"^sp/", include("socialprofile.urls")),
)


# @># Server Errors Handlers
handler400 = errors_views.custom_400
""" Handle 400 error """

handler403 = errors_views.custom_403
""" Handle 403 error """

handler404 = errors_views.custom_404
""" Handle 404 error """

handler500 = errors_views.custom_500
""" Handle 500 error """



# Generated by Django 2.2.24 on 2021-11-29 21:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0015_auto_20211129_2117"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialprofile",
            name="google_username",
            field=models.CharField(
                blank=True, max_length=30, verbose_name="Google Username"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="instagram_url",
            field=models.URLField(
                blank=True, max_length=500, null=True, verbose_name="Instagram Profile"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_username",
            field=models.CharField(
                blank=True, max_length=30, verbose_name="Twitter Username"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="username_facebook",
            field=models.CharField(
                blank=True, max_length=30, verbose_name="Facebook Username"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="username_instagram",
            field=models.CharField(
                blank=True, max_length=30, verbose_name="Instagram Username"
            ),
        ),
    ]



from rest_framework import serializers

from socialprofile.models import SocialProfile


# Serializers define the API representation.
class SocialProfileSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = SocialProfile
        fields = ("url", "username", "email", "is_staff")



"""Test's view for django-errors"""

from django.http import (
    HttpResponse,
    HttpResponseBadRequest,
    HttpResponseForbidden,
    HttpResponseNotAllowed,
    HttpResponseNotFound,
    HttpResponseServerError,
)
from django.views.decorators.http import require_http_methods


def test_view(request):
    """Test's view"""
    if request.method != "GET":
        return HttpResponseNotFound("404 view")
    return HttpResponse("Test view")


def test_view_400(request):
    """Test's view code 400"""
    return HttpResponseBadRequest("400 view")


def test_view_403(request):
    """Test's view code 403"""
    return HttpResponseForbidden("403 view")


@require_http_methods(["POST"])
def test_view_405(request):
    """Test's view code 405"""
    return HttpResponseNotAllowed("405 view")


def test_view_500(request):
    """Test's view code 400"""
    return HttpResponseServerError("500 view")



# Generated by Django 2.2.18 on 2021-02-14 16:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0008_auto_20201117_1209"),
    ]

    operations = [
        migrations.RenameField(
            model_name="socialprofile",
            old_name="manually_edited",
            new_name="edited_by_user",
        ),
        migrations.RemoveField(
            model_name="socialprofile",
            name="editByGoogle",
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="edited_by_provider",
            field=models.NullBooleanField(
                default=False, verbose_name="Provider Edit User's Info"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_language",
            field=models.CharField(
                blank=True, max_length=2, null=True, verbose_name="Twitter Language"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_verified",
            field=models.NullBooleanField(
                default=False, verbose_name="Twitter Verified"
            ),
        ),
    ]



"""
See PEP 386 (http://www.python.org/dev/peps/pep-0386/)
Release logic:
1. Remove "dev" from current.
2. git commit
3. git tag <version>
4. push to pypi + push to github
5. bump the version, append '.dev0'
6. git commit
7. push to github (to avoid confusion)
"""

import django

__version__ = "1.23.3"
__license__ = "MIT"
__title__ = "django-errors"

__author__ = "DLRSP"
__copyright__ = "Copyright 2010-present DLRSP"

# Version synonym
VERSION = __version__

# Header encoding (see RFC5987)
HTTP_HEADER_ENCODING = "iso-8859-1"

# Default datetime input and output formats
ISO_8601 = "iso-8601"

if django.VERSION < (3, 2):
    default_app_config = "socialprofile.apps.SocialProfileConfig"



# Generated by Django 4.2.4 on 2023-08-05 15:45

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0027_delete_proxy_phonedevice"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="proxysession",
            options={
                "verbose_name": "Monitor: session",
                "verbose_name_plural": "Monitor: sessions",
            },
        ),
    ]
